from prijsoog.supermarkets.ah import AhWatcher
from prijsoog.supermarkets.jumbo import JumboWatcher

__author__ = """Pepijn Boers"""
__email__ = "pepijnbb@gmail.com"
__version__ = "__version__ = '0.1.7'"
__all__ = ["AhWatcher", "JumboWatcher"]
